@@ -8,13 +8,13 @@ Siebel::Srvrmgr::ListParser::Output - base class of srvrmgr output
 
 =head1 SYNOPSIS
 
-	use Siebel::Srvrmgr::ListParser::Output;
-
-	my $output = Siebel::Srvrmgr::ListParser::Output->new({ data_type => 'sometype', 
-															raw_data => \@data, 
-															cmd_line => 'list something from somewhere'});
-
-	$output->store($complete_pathname);
+    use Siebel::Srvrmgr::ListParser::Output;
+    my $output = Siebel::Srvrmgr::ListParser::Output->new({
+        data_type => 'sometype', 
+        raw_data => \@data, 
+        cmd_line => 'list something from somewhere'
+    });
+    $output->store($complete_pathname);
 
 =cut
 
@@ -22,7 +22,7 @@ use Moose 2.0401;
 use namespace::autoclean 0.13;
 use Carp;
 use Siebel::Srvrmgr::Regexes qw(ROWS_RETURNED);
-our $VERSION = '0.25'; # VERSION
+our $VERSION = '0.26'; # VERSION
 
 =pod
 
