@@ -12,7 +12,8 @@ use Moose 2.0401;
 use namespace::autoclean 0.13;
 use Siebel::Srvrmgr::ListParser::Output::ListComp::Server;
 use Siebel::Srvrmgr::ListParser::Output::ListComp::Comp;
-our $VERSION = '0.25'; # VERSION
+
+our $VERSION = '0.26'; # VERSION
 
 =head1 SYNOPSIS
 
@@ -38,17 +39,17 @@ can see below:
         SV_NAME (31):  Server name
         CC_ALIAS (31):  Component alias
         CC_NAME (76):  Component name
-        CT_ALIAS (31):  Component type alias
+        CT_ALIAS (61):  Component type alias
         CG_ALIAS (31):  Component Group Alias
         CC_RUNMODE (31):  Component run mode (enum)
         CP_DISP_RUN_STATE (61):  Component display run state
+        CP_STARTMODE (16):  Component Start Mode
         CP_NUM_RUN_TASKS (11):  Current number of running tasks
         CP_MAX_TASKS (11):  Maximum tasks configured
         CP_ACTV_MTS_PROCS (11):  Active MTS control processes
         CP_MAX_MTS_PROCS (11):  Maximum MTS control processes
         CP_START_TIME (21):  Component start time
         CP_END_TIME (21):  Component end time
-        CP_STATUS (251):  Component-reported status
         CC_INCARN_NO (23):  Incarnation Number
         CC_DESC_TEXT (251):  Component description
 
@@ -63,6 +64,7 @@ This output above should be the default but it will be necessary to have the con
         CG_ALIAS (31):  Component GRoup Alias
         CC_RUNMODE (31):  Component run mode (enum)
         CP_DISP_RUN_STATE (61):  Component display run state
+        CP_STARTMODE (16):  Component Start Mode
         CP_NUM_RUN_TASKS (16):  Current number of running tasks
         CP_MAX_TASKS (12):  Maximum tasks configured
         CP_ACTV_MTS_PROCS (17):  Active MTS control processes
@@ -80,10 +82,9 @@ from the expected.
 To enable that, execute the following commands in the C<srvrmgr> program:
 
     set ColumnWidth true
-    
-    configure list components show SV_NAME(31), CC_ALIAS(31), CC_NAME(76), CT_ALIAS(31), CG_ALIAS(31), CC_RUNMODE(31), CP_DISP_RUN_STATE(61),\
-    CP_NUM_RUN_TASKS(16), CP_MAX_TASKS(12), CP_ACTV_MTS_PROCS(17), CP_MAX_MTS_PROCS(16), CP_START_TIME(21), CP_END_TIME(21),\
-    CP_STATUS(251), CC_INCARN_NO(23), CC_DESC_TEXT(251)
+    configure list components show SV_NAME(31) , CC_ALIAS(31) , CC_NAME(76) , CT_ALIAS(31) , CG_ALIAS(31) , CC_RUNMODE(31) , CP_DISP_RUN_STATE(61) ,\
+    CP_STARTMODE(16), CP_NUM_RUN_TASKS(16) , CP_MAX_TASKS(12) , CP_ACTV_MTS_PROCS(17) , CP_MAX_MTS_PROCS(16) , CP_START_TIME(21) , CP_END_TIME(21) ,\
+    CP_STATUS(251) , CC_INCARN_NO(23) , CC_DESC_TEXT(251)
 
 Saving this configuration as a preference and loading it everytime is a good idea too.
 
@@ -146,15 +147,29 @@ has 'servers' => (
 =cut
 
 sub _build_expected {
-
     my $self = shift;
-
     $self->_set_expected_fields(
         [
             'SV_NAME',,
-            'CC_ALIAS',          'CC_NAME',
-            'CT_ALIAS',          'CG_ALIAS',
-            'CC_RUNMODE',        'CP_DISP_RUN_STATE',
+            'CC_ALIAS',         'CC_NAME',
+            'CT_ALIAS',         'CG_ALIAS',
+            'CC_RUNMODE',       'CP_DISP_RUN_STATE',
+            'CP_STARTMODE',     'CP_NUM_RUN_TASKS',
+            'CP_MAX_TASKS',     'CP_ACTV_MTS_PROCS',
+            'CP_MAX_MTS_PROCS', 'CP_START_TIME',
+            'CP_END_TIME',      'CP_STATUS',
+            'CC_INCARN_NO',     'CC_DESC_TEXT'
+        ]
+    );
+}
+
+sub _build_comp_attribs {
+    my $self = shift;
+    $self->_set_comp_attribs(
+        [
+            'CC_NAME',           'CT_ALIAS',
+            'CG_ALIAS',          'CC_RUNMODE',
+            'CP_DISP_RUN_STATE', 'CP_STARTMODE',
             'CP_NUM_RUN_TASKS',  'CP_MAX_TASKS',
             'CP_ACTV_MTS_PROCS', 'CP_MAX_MTS_PROCS',
             'CP_START_TIME',     'CP_END_TIME',
@@ -162,25 +177,6 @@ sub _build_expected {
             'CC_DESC_TEXT'
         ]
     );
-
-}
-
-sub _build_comp_attribs {
-
-    my $self = shift;
-
-    $self->_set_comp_attribs(
-        [
-            'CC_NAME',           'CT_ALIAS',
-            'CG_ALIAS',          'CC_RUNMODE',
-            'CP_DISP_RUN_STATE', 'CP_NUM_RUN_TASKS',
-            'CP_MAX_TASKS',      'CP_ACTV_MTS_PROCS',
-            'CP_MAX_MTS_PROCS',  'CP_START_TIME',
-            'CP_END_TIME',       'CP_STATUS',
-            'CC_INCARN_NO',      'CC_DESC_TEXT'
-        ]
-    );
-
 }
 
 =pod
@@ -207,12 +203,9 @@ object. Otherwise it will return C<undef>.
 =cut
 
 sub get_server {
-
-    my $self       = shift;
-    my $servername = shift;
+    my ( $self, $servername ) = @_;
 
     if ( exists( $self->get_data_parsed()->{$servername} ) ) {
-
         return Siebel::Srvrmgr::ListParser::Output::ListComp::Server->new(
             {
                 name         => $servername,
@@ -220,60 +213,42 @@ sub get_server {
                 comp_attribs => $self->get_comp_attribs()
             }
         );
-
     }
     else {
-
         return;
-
     }
-
 }
 
 sub _set_last_server {
-
-    my $self   = shift;
-    my $server = shift;
-
+    my ( $self, $server ) = @_;
     $self->__set_last_server($server);
     push( @{ $self->get_servers() }, $server );
-
 }
 
 sub _consume_data {
-
-    my $self       = shift;
-    my $fields_ref = shift;
-    my $parsed_ref = shift;
-
+    my ( $self, $fields_ref, $parsed_ref ) = @_;
     confess 'invalid fields parameter'
       unless ( ( defined($fields_ref) )
         and ( ( ref($fields_ref) ) eq 'ARRAY' )
         and ( ( scalar( @{$fields_ref} ) ) > 0 ) );
-
     my $server = shift( @{$fields_ref} );
 
     # do not need the servername again
     if (   ( $self->get_last_server() eq '' )
         or ( $self->get_last_server() ne $server ) )
     {
-
         $self->_set_last_server($server);
-
     }
 
     my $comp_alias = shift( @{$fields_ref} );
-
-    my $list_len = scalar( @{$fields_ref} );
+    my $list_len   = scalar( @{$fields_ref} );
 
 # :TODO      :08/05/2013 18:19:48:: replace comp_attribs with header_cols? seems to be the same thing
     my $columns_ref = $self->get_comp_attribs();
-
     confess "Cannot continue without defining fields names"
       unless ( defined($columns_ref) );
 
     if ( @{$fields_ref} ) {
-
         my $server = $self->get_last_server();
 
         for ( my $i = 0 ; $i < $list_len ; $i++ ) {
@@ -283,18 +258,13 @@ sub _consume_data {
 # hash reference to keep column_name => value
             $parsed_ref->{$server}->{$comp_alias}->{ $columns_ref->[$i] } =
               $fields_ref->[$i];
-
         }
 
         return 1;
-
     }
     else {
-
         return 0;
-
     }
-
 }
 
 =pod
