@@ -5,8 +5,9 @@ use strict;
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK =
-  qw(SRVRMGR_PROMPT LOAD_PREF_RESP LOAD_PREF_CMD CONN_GREET SIEBEL_ERROR ROWS_RETURNED SIEBEL_SERVER);
-our $VERSION = '0.25'; # VERSION
+  qw(SRVRMGR_PROMPT LOAD_PREF_RESP LOAD_PREF_CMD CONN_GREET SIEBEL_ERROR ROWS_RETURNED SIEBEL_SERVER prompt_slices);
+our %EXPORT_TAGS = ( all => [@EXPORT_OK] );
+our $VERSION = '0.26'; # VERSION
 
 =pod
 
@@ -19,39 +20,93 @@ Siebel::Srvrmgr::Regexes - common regular expressions to match things in srvrmgr
     use Siebel::Srvrmgr::Regexes qw(SRVRMGR_PROMPT);
 
     if($line =~ /SRVRMGR_PROMPT/) {
-
         #do something
-
     }
 
 =head1 DESCRIPTION
 
 This modules exports several pre-compiled regular expressions by demand.
 
+To get all regular expressions, you can use the tag C<:all>;
+
 =head1 EXPORTS
 
 =head2 SRVRMGR_PROMPT
 
-Regular expression to match the C<srvrmgr> prompt, with or without any command. It will match the server name, if included.
+Regular expression to match the C<srvrmgr> prompt, with or without the Siebel server name and/or command.
 
 =cut
 
+# this will be reused by more than one sub
+my $server_regex = '[[:alpha:]][\w\_]{1,11}';
+
+# :WARNING:09/22/2016 10:11:10 PM:: be very careful to change SRVRMGR_PROMPT, Siebel::Srvrmgr::ListParser::FSA depends a lot on it!
 sub SRVRMGR_PROMPT {
+    return qr/^srvrmgr(\:$server_regex)?>(\s.*)?$/;
+}
 
-    return qr/^srvrmgr(\:[\w\_\-]+)?>\s(.*)?$/;
+=head2 prompt_slices
 
+This sub will use the SRVRMGR_PROMPT regular expression to try and match all the pieces of information that can be included into the C<srvrmgr> prompt:
+
+=over
+
+=item *
+
+the Siebel Server name
+
+=item *
+
+the executed command
+
+=back
+
+It expects as parameter the corresponding string of a C<srvrmgr> prompt. It will then return a list of two values: Siebel Server Name and the executed command.
+Those files can be undefined depending on the string given as parameter, so they should be tested before use.
+
+This helper function was created because it is a common case to search for both string in the prompt, it should help avoiding impacts to other parts of the
+API given changes made to the SRVRMGR_PROMPT regular expression, but you can always fetch the values from it directly.
+
+Additionally, this sub will also remove any character that is not part of the slices (colon and spaces).
+
+When using this function, be sure to do it like:
+    my ($server,$command) = prompt_slices($my_prompt);
+
+=cut
+
+sub prompt_slices {
+    my $prompt = shift;
+    my ( $server, $cmd );
+    $prompt =~ SRVRMGR_PROMPT;
+
+    if ( defined($1) ) {
+        $server = $1;
+        $server =~ tr/://d;
+    }
+
+    if ( defined($2) ) {
+
+        if ( $2 eq ' ' ) {
+            $cmd = undef;
+        }
+        else {
+            $cmd = $2;
+            $cmd =~ s/^\s+//;
+            $cmd =~ s/\s+$//;
+        }
+    }
+
+    return $server, $cmd;
 }
 
 =head2 SIEBEL_SERVER
 
-Regular expression to match a valid Siebel Server name.
+Regular expression to match a valid Siebel Server name. See L<https://docs.oracle.com/cd/E14004_01/books/SiebInstUNIX/SiebInstCOM_Requirements21.html#wp1333940>.
 
 =cut
 
 sub SIEBEL_SERVER {
-
-    return qr/^([\w\_\-]+)$/;
-
+    return qr/^$server_regex$/;
 }
 
 =pod
@@ -63,7 +118,7 @@ Regular expression to match the C<load preferences> response once the command is
 =cut
 
 sub LOAD_PREF_RESP {
-    return qr/^(srvrmgr(\:[\w\_\-]+)?>)?\s?File\:\s.*\.pref$/;
+    return qr/^(srvrmgr(\:$server_regex)?>)?\s?File\:\s.*\.pref$/;
 }
 
 =pod
@@ -74,7 +129,9 @@ Regular expression to match the C<load preferences> command when submitted.
 
 =cut
 
-sub LOAD_PREF_CMD { return qr/^(srvrmgr(\:[\w\_\-]+)?>)?\s?load preferences$/; }
+sub LOAD_PREF_CMD {
+    return qr/^(srvrmgr(\:$server_regex)?>)?\s?load preferences$/;
+}
 
 =pod
 
@@ -106,9 +163,7 @@ This line indicated how many rows were returned by a command.
 =cut
 
 sub ROWS_RETURNED {
-
     return qr/^\d+\srows?\sreturned\./;
-
 }
 
 =pod
@@ -125,9 +180,7 @@ The regular expression matches the default error code.
 =cut
 
 sub SIEBEL_ERROR {
-
     return qr/^SBL\-\w{3}\-\d+/;
-
 }
 
 =head1 AUTHOR
